@@ -1,7 +1,8 @@
 "dist.list" <-
 function() {
   dist <- c("cau","exp","gam","gev","gld","glo","gno",
-            "gpa","gum","kap","nor","pe3","wak","wei");
+            "gpa","gum","kap","nor","pe3","wak",
+            "wei");
   return(dist)
 } 
 
