@@ -2,13 +2,13 @@
 function(data) {
    lmom <- lmom.ub(data)
    para <- pargpa(lmom)
-   print("GENERALIZED PARETO DISTRIBUTION PARAMETERS")
-   print(para)
+   cat("GENERALIZED PARETO DISTRIBUTION PARAMETERS\n")
+   str(para)
    lmompara <- lmomgpa(para)
    Q50 <- quagpa(0.5,para)
-   print(c('MEDIAN ',Q50))
+   cat(c("Computed median=",Q50,"\n"),sep="")
    P50 <- cdfgpa(Q50,para)
-   print(c('NONEXCEEDANCE OF COMPUTED MEDIAN ',P50))
+   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
    lmom.diff(lmompara,lmom)
 }
 
